/**
 * This is a helper script that is meant to make it easy to create new files in an appropriate folder
 * The values below have been hardcoded to a specific users environment, so they will need to be updated
 */
const fs = require('fs');



let type = '';
let filename = '';

process.argv.forEach((arg, index) => {
    if (index <= 1) return;
    if (index === 2) type = arg;
    if (index === 3) filename = arg;
});

if (type !== 'context' && type !== 'component' && type !== 'element' && type !== 'override') {
    console.log('Invalid type. Please use one of; \'context\', \'component\', \'element\', \'override\'. The script will pluralize');
    console.log(`Currently '${type}'`);
    return;
}

const placeholderContent = `/**
 * Placeholder styling for ${filename}
 */
& {
  
}
`;
const outlineContent = `/**
 * ${filename} styling
 */
.${filename} {
  @import 'aligent-scss-placeholder/${type}s/${filename}';
}
`;

// Create the new file in the Placeholder directory
fs.writeFile(`./${type}s/_${filename}.scss`, placeholderContent, (err) => {
    if (err) {
        console.log(err);
    }
});

/**
 * Ensure a new file is also created in the AligentSCSSOutline repository
 * This is usually what we will want to do, as the file in the Outline will have all of the selectors that are created
 * in the Placeholder file, just without any actual styles
 */
const outlineDir = '[path-to-directory]';
// Simple check to make sure users know that they will need to update the outlineDir value above, in this file directly
if (outlineDir === '[path-to-directory]') {
    console.log('Please set the outlineDir variable in the create-file.js script');
    process.exit();
}
fs.writeFile(`${outlineDir}${type}s/_${filename}.scss`, outlineContent, (err) => {
    if (err) {
        console.log(err);
    }
});

/**
 * Uncomment the block below to ensure a new file is also created in a project.
 * This could be helpful when developing the Placeholder
 */
// const projectDir = '//home/luke.denton/sites/bbnt-m2-dev/magento/app/design/frontend/bbnt/base/source/scss/';
// fs.writeFile(`${projectDir}${type}s/_${filename}.scss`, outlineContent, (err) => {
//     if (err) {
//         console.log(err);
//     }
// });
